# -*- coding: utf-8 -*-
# ------------------------------------------------------------------------------
#
#   Copyright 2021-2022 Valory AG
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# ------------------------------------------------------------------------------

"""This module contains an abstract round ABCI skill template for an AEA."""  # pragma: nocover

from aea.configurations.base import PublicId  # pragma: nocover
from hypothesis import settings  # pragma: nocover


PUBLIC_ID = PublicId.from_str("valory/abstract_round_abci:0.1.0")
CI = "CI"  # pragma: nocover


settings.register_profile(CI, deadline=5000)  # pragma: nocover
